DORMANTno replies

[JGIT PATCH] Fix spelling of Junit option jgit.junit.usemmap

From: Robin Rosenberg <hidden>
Date: 2016-06-15 22:46:40
Subsystem: the rest · Maintainer: Linus Torvalds

Signed-off-by: Robin Rosenberg <redacted>
---
 .../org/spearce/jgit/lib/RepositoryTestCase.java   |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/org.spearce.jgit.test/tst/org/spearce/jgit/lib/RepositoryTestCase.java b/org.spearce.jgit.test/tst/org/spearce/jgit/lib/RepositoryTestCase.java
index b85d3eb..3b03ac1 100644
--- a/org.spearce.jgit.test/tst/org/spearce/jgit/lib/RepositoryTestCase.java
+++ b/org.spearce.jgit.test/tst/org/spearce/jgit/lib/RepositoryTestCase.java
@@ -61,7 +61,7 @@
  * Sets up a predefined test repository and has support for creating additional
  * repositories and destroying them when the tests are finished.
  *
  * A system property <em>jgit.junit.usemmmap</em> defines whether memory mapping
  * is used. Memory mapping has an effect on the file system, in that memory
  * mapped files in java cannot be deleted as long as they mapped arrays have not
  * been reclaimed by the garbage collector. The programmer cannot control this
@@ -123,7 +123,7 @@ protected void configure() {
 		final WindowCacheConfig c = new WindowCacheConfig();
 		c.setPackedGitLimit(128 * WindowCacheConfig.KB);
 		c.setPackedGitWindowSize(8 * WindowCacheConfig.KB);
-		c.setPackedGitMMAP("true".equals(System.getProperty("jgit.junit.usemmmap")));
+		c.setPackedGitMMAP("true".equals(System.getProperty("jgit.junit.usemmap")));
 		c.setDeltaBaseCacheLimit(8 * WindowCacheConfig.KB);
 		WindowCache.reconfigure(c);
 	}
@@ -61,7 +61,7 @@
  * repositories and destroying them when the tests are finished.
  *
- * A system property <em>jgit.junit.usemmmap</em> defines whether memory mapping
+ * A system property <em>jgit.junit.usemmap</em> defines whether memory mapping
  * is used. Memory mapping has an effect on the file system, in that memory
  * mapped files in java cannot be deleted as long as they mapped arrays have not
-- 
1.6.3.rc2.1.g868b6
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help